# ADR [number]: [Title]

Date: [YYYY-MM-DD]

## Status

[Proposed | Accepted | Deprecated | Superseded by ADR-XXXX]

## Context

What is the issue we're seeing that is motivating this decision or change? This section describes the forces at play, including:

- Technical constraints
- Business requirements
- Architectural principles
- Current pain points
- Alternative approaches considered

## Decision

What is the change that we're proposing or have agreed to implement? This should be stated clearly and concisely.

Describe the architecture or approach in enough detail that someone with context in the project can understand the decision and implementation.

## Consequences

What becomes easier or more difficult because of this change?

### Positive Consequences

- Benefit 1
- Benefit 2
- ...

### Negative Consequences

- Trade-off 1
- Complexity introduced 2
- ...

### Risks and Mitigations

- **Risk**: Description of potential risk
  - **Mitigation**: How we address this risk

## Implementation Notes

Optional section for key implementation details:

- File locations
- Key classes/modules
- Integration points
- Migration strategy

## References

- Links to related ADRs
- Links to relevant documentation
- Links to issues or discussions
- Related design documents
